@@ -1,6 +1,7 @@
 use async_trait::async_trait;
 
 use crate::http::{Request, Response};
+use crate::routing::FlowCtrl;
 use crate::Depot;
 
 /// Handler trait for handle http request.
@@ -8,5 +9,5 @@ use crate::Depot;
 pub trait Handler: Send + Sync + 'static {
     /// Handle http request.
     #[must_use = "handle future must be used"]
-    async fn handle(&self, req: &mut Request, depot: &mut Depot, res: &mut Response);
+    async fn handle(&self, req: &mut Request, depot: &mut Depot, res: &mut Response, ctrl: &mut FlowCtrl);
 }
